@@ -1,7 +1,4 @@
 #line 1 "inc/Module/Install/AutoInstall.pm - lib/Module/Install/AutoInstall.pm"
-# $File: //depot/cpan/Module-Install/lib/Module/Install/AutoInstall.pm $ $Author: autrijus $
-# $Revision: #12 $ $Change: 1481 $ $DateTime: 2003/05/07 10:41:22 $ vim: expandtab shiftwidth=4
-
 package Module::Install::AutoInstall;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
@@ -39,6 +36,10 @@ manually install $p $v from cpan.org first...\n"}}}
     my @core = map @$_, map @$_, grep ref,
                $self->build_requires, $self->requires;
 
+    while ( @core and @_ > 1 and $_[0] =~ /^-\w+$/ ) {
+        push @core, splice(@_, 0, 2);
+    }
+
     ExtUtils::AutoInstall->import(
         (@core ? (-core => \@core) : ()), @_, $self->features
     );
